Video — Kivy v1.0.1-dev documentation

# Video

Core class for reading video file and manage the `kivy.graphics.texture.Texture` video.

Note

Recording is not supported.

class `kivy.core.video.` `VideoBase`(**kwargs)

  Bases: `kivy.event.EventDispatcher`

  VideoBase, a class to implement a video reader.

  Parameters : | filename : str Filename of the video. Can be a file or an URI. eos : str, default to ‘pause’ Action to do when EOS is hit. Can be one of ‘pause’ or ‘loop’ async : bool, default to True Asynchronous loading (may be not supported by all providers) autoplay : bool, default to False Auto play the video at init
  Events : | on_eos Fired when EOS is hit on_load Fired when the video is loaded, texture is available on_frame Fired when a new frame is written on texture

  `duration`

    Get the video duration (in seconds)

  `filename`

    Get/set the filename/uri of current video

  `load`()

    Load the video from the current filename

  `play`()

    Play the video

  `position`

    Get/set the position in the video (in seconds)

  `seek`(percent)

    Move on percent position

  `state`

    Get the video playing status

  `stop`()

    Stop the video playing

  `texture`

    Get the video texture

  `unload`()

    Unload the actual video

  `volume`

    Get/set the volume in the video (1.0 = 100%)